@@ -1637,6 +1637,7 @@ static void gps_location_changed(LocationGPSDevice *device, gpointer userdata)
 
   GPSData                               &gpsData=window->data;
 
+  gpsData.SetConnected(true);
   gpsData.SetOnline(device->online);
   gpsData.SetFix(device->status!=LOCATION_GPS_DEVICE_STATUS_NO_FIX);
 
@@ -1651,10 +1652,10 @@ static void gps_location_changed(LocationGPSDevice *device, gpointer userdata)
     gpsData.SetLatitude(fix->latitude);
   }
   if (fix->fields & LOCATION_GPS_DEVICE_LATLONG_SET && !isnan(fix->longitude)) {
-    gpsData.SetLatitude(fix->longitude);
+    gpsData.SetLongitude(fix->longitude);
   }
   if (fix->fields & LOCATION_GPS_DEVICE_ALTITUDE_SET && !isnan(fix->altitude)) {
-    gpsData.SetLatitude(fix->altitude);
+    gpsData.SetAltitude(fix->altitude);
   }
   if (fix->fields & LOCATION_GPS_DEVICE_SPEED_SET && !isnan(fix->speed)) {
     gpsData.SetSpeed(fix->speed);
